@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -10,12 +11,13 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
- 'BINLIBDEST': '/usr/local/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
- 'BLDSHARED': 'cc -pthread -shared -fPIC',
+ 'BINLIBDEST': '/usr/local/lib/python3.9',
+ 'BLDLIBRARY': '-L. -lpython3.9',
+ 'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
+              '-L/usr/ports/pobj/Python-3.9.7/Python-3.9.7 -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'arm-unknown-openbsd7.1',
+ 'BUILD_GNU_TYPE': 'powerpc64-unknown-openbsd7.0',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
@@ -23,6 +25,7 @@ build_time_vars = {'ABIFLAGS': '',
            '-pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
+ 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe',
@@ -30,32 +33,35 @@ build_time_vars = {'ABIFLAGS': '',
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-fpectl' '--with-threads' "
-                "'--enable-ipv6' '--with-system-expat' '--with-system-ffi' "
-                "'--enable-loadable-sqlite-extensions' '--prefix=/usr/local' "
-                "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
-                "'--infodir=/usr/local/info' '--localstatedir=/var' "
-                "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
-                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
-                "'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-loadable-sqlite-extensions' "
+                "'--enable-shared' "
+                "'--srcdir=/usr/ports/pobj/Python-3.9.7/Python-3.9.7' "
+                "'--with-fpectl' '--with-threads' '--enable-ipv6' "
+                "'--with-system-expat' '--with-system-ffi' "
+                "'--prefix=/usr/local' '--sysconfdir=/etc' "
+                "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
+                "'--localstatedir=/var' '--disable-silent-rules' "
+                "'--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' "
+                "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
- 'CONFINCLUDEPY': '/usr/local/include/python3.8',
+ 'CONFINCLUDEPY': '/usr/local/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.8.13/Python-3.8.13/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.8.13/Python-3.8.13/lcov-report',
+ 'COVERAGE_INFO': '/usr/ports/pobj/Python-3.9.7/Python-3.9.7/coverage.info',
+ 'COVERAGE_REPORT': '/usr/ports/pobj/Python-3.9.7/Python-3.9.7/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.8 '
-             '/usr/local/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/local/lib/python3.8',
+ 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.9 '
+             '/usr/local/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/usr/local/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/local/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/usr/local/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -66,25 +72,26 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
  'DTRACE_OBJS': '',
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
- 'ENSUREPIP': 'upgrade',
+ 'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-38.so',
+ 'EXT_SUFFIX': '.cpython-39.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 0,
+ 'FLOAT_WORDS_BIGENDIAN': 1,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -207,7 +214,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -240,7 +247,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 0,
  'HAVE_GETSPNAM': 0,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -259,7 +265,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -276,14 +282,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_J1939_H': 0,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 0,
  'HAVE_LINUX_MEMFD_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_QRTR_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LINUX_VM_SOCKETS_H': 0,
+ 'HAVE_LINUX_WAIT_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -309,6 +318,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 0,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -335,7 +345,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 0,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 0,
@@ -487,7 +496,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 1,
  'HAVE_UTIMENSAT': 1,
@@ -510,36 +518,39 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'arm-unknown-openbsd7.1',
+ 'HOST_GNU_TYPE': 'powerpc64-unknown-openbsd7.0',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
-                   '/usr/local/include/python3.8 /usr/local/include/python3.8',
+                   '/usr/local/include/python3.9 /usr/local/include/python3.9',
  'INCLUDEDIR': '/usr/local/include',
- 'INCLUDEPY': '/usr/local/include/python3.8',
- 'INSTALL': '/usr/obj/ports/Python-3.8.13/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.8.13/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.8.13/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.8.13/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.8.13/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.0.0',
+ 'INCLUDEPY': '/usr/local/include/python3.9',
+ 'INSTALL': '/usr/ports/pobj/Python-3.9.7/bin/install -c',
+ 'INSTALL_DATA': '/usr/ports/pobj/Python-3.9.7/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/ports/pobj/Python-3.9.7/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/ports/pobj/Python-3.9.7/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/ports/pobj/Python-3.9.7/bin/install -c -m 755',
+ 'INSTSONAME': 'libpython3.9.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/ports/pobj/Python-3.9.7/Python-3.9.7 '
+            '-L/usr/local/lib/',
+ 'LDFLAGS_NODIST': '',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -pthread -shared -fPIC',
- 'LDVERSION': '3.8',
+ 'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
+             '-L/usr/ports/pobj/Python-3.9.7/Python-3.9.7 -L/usr/local/lib/',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/usr/local/lib/python3.8',
+ 'LIBDEST': '/usr/local/lib/python3.9',
  'LIBDIR': '/usr/local/lib',
  'LIBFFI_INCLUDEDIR': '/usr/local/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/local/lib/pkgconfig',
- 'LIBPL': '/usr/local/lib/python3.8/config-3.8',
+ 'LIBPL': '/usr/local/lib/python3.9/config-3.9',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lintl -lpthread  -lutil -lm',
@@ -555,7 +566,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'openbsd7',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/local/lib/python3.8',
+ 'MACHDESTLIB': '/usr/local/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -566,7 +577,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -579,7 +590,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
@@ -599,9 +610,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '',
  'PGO_PROF_USE_FLAG': '',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -617,9 +632,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                              '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
                              '-O2 -pipe -O2 -pipe -std=c99 -Wextra '
@@ -627,29 +642,32 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-I/usr/local/include -I./Include/internal -I. '
-                             '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -I/usr/local/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
               '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-I/usr/local/include -I./Include/internal',
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
                    '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
                    '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -I/usr/local/include '
-                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -I/usr/local/include '
+                   '-fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
+                    '-L/usr/ports/pobj/Python-3.9.7/Python-3.9.7 '
                     '-L/usr/local/lib/',
- 'PY_CPPFLAGS': '-I. -I./Include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-L/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
-                      '-L/usr/local/lib/',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/ports/pobj/Python-3.9.7/Python-3.9.7 '
+               '-L/usr/local/lib/',
+ 'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
@@ -658,8 +676,8 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-I/usr/local/include -I./Include/internal -I. '
-                        '-I./Include -fPIC',
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -668,7 +686,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.13/Python-3.8.13',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/ports/pobj/Python-3.9.7/Python-3.9.7',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -682,22 +700,22 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG': 8,
  'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-39',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -710,20 +728,21 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/ports/pobj/Python-3.9.7/Python-3.9.7 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/ports/pobj/Python-3.9.7/Python-3.9.7 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.8',
+ 'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -735,8 +754,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.8.13/Python-3.8.13',
- 'abs_srcdir': '/usr/obj/ports/Python-3.8.13/Python-3.8.13',
+ 'abs_builddir': '/usr/ports/pobj/Python-3.9.7/Python-3.9.7',
+ 'abs_srcdir': '/usr/ports/pobj/Python-3.9.7/Python-3.9.7',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
